You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
1
(9) |
2
(2) |
3
(9) |
4
(19) |
5
(4) |
6
(1) |
7
(6) |
|
8
(11) |
9
(30) |
10
(12) |
11
(25) |
12
(7) |
13
(5) |
14
|
|
15
(17) |
16
(15) |
17
(20) |
18
(17) |
19
(5) |
20
(4) |
21
|
|
22
|
23
|
24
|
25
|
26
|
27
(4) |
28
(15) |
|
29
(10) |
30
(9) |
31
(11) |
|
|
|
|
|
From: Florian K. <br...@ac...> - 2011-05-30 22:20:39
|
Greetings. Attached are the results from a new run of IBM's BEAM checker. In my previous post I had asked for feedback on complaints regarding constant conditions. Julian has given me his 5 cents. I'd be interested to hear from the callgrind / cachegrind maintainers about their preference WRT those findings. Shall I include them in future runs or not? Here is the breakdown of all complaints: coregrind 13 +1 callgrind 3 +1 cachegrind 2 memcheck 2 The third column shows the change as compared to the previous run. As always, let me know if a complaint is harmless and I will suppress it in future reports. There will be no further BEAM results until sometime in late June as I will be on vacation. Cheers, Florian |
|
From: Christian B. <bor...@de...> - 2011-05-30 20:26:02
|
Nightly build on sless390 ( SUSE Linux Enterprise Server 11 SP1 gcc 4.3.4 on z196 (s390x) )
Started at 2011-05-30 22:10:01 CEST
Ended at 2011-05-30 22:25:49 CEST
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 476 tests, 6 stderr failures, 0 stdout failures, 3 stderrB failures, 0 stdoutB failures, 0 post failures ==
gdbserver_tests/mcbreak (stderrB)
gdbserver_tests/mcclean_after_fork (stderrB)
gdbserver_tests/mssnapshot (stderrB)
none/tests/faultstatus (stderr)
helgrind/tests/tc06_two_races_xml (stderr)
helgrind/tests/tc23_bogus_condwait (stderr)
drd/tests/tc04_free_lock (stderr)
drd/tests/tc09_bad_unlock (stderr)
drd/tests/tc23_bogus_condwait (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vki.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vki.Tpo -c -o libcoregrind_s390x_linux_a-m_vki.o `test -f 'm_vki.c' || echo './'`m_vki.c
mv -f .deps/libcoregrind_s390x_linux_a-m_oset.Tpo .deps/libcoregrind_s390x_linux_a-m_oset.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vkiscnums.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Tpo -c -o libcoregrind_s390x_linux_a-m_vkiscnums.o `test -f 'm_vkiscnums.c' || echo './'`m_vkiscnums.c
m_translate.c: In function 'vgPlain_translate':
m_translate.c:1548: error: 'VexTranslateArgs' has no member named 'dispatch'
make[3]: *** [libcoregrind_s390x_linux_a-m_translate.o] Error 1
make[3]: *** Waiting for unfinished jobs....
mv -f .deps/libcoregrind_s390x_linux_a-m_vki.Tpo .deps/libcoregrind_s390x_linux_a-m_vki.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Tpo .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_tooliface.Tpo .deps/libcoregrind_s390x_linux_a-m_tooliface.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_signals.Tpo .deps/libcoregrind_s390x_linux_a-m_signals.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_mallocfree.Tpo .deps/libcoregrind_s390x_linux_a-m_mallocfree.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo .deps/libcoregrind_s390x_linux_a-m_transtab.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_main.Tpo .deps/libcoregrind_s390x_linux_a-m_main.Po
make[3]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old/coregrind'
make[2]: *** [all] Error 2
make[2]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old/coregrind'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Mon May 30 22:10:56 2011
--- new.short Mon May 30 22:25:49 2011
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vki.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vki.Tpo -c -o libcoregrind_s390x_linux_a-m_vki.o `test -f 'm_vki.c' || echo './'`m_vki.c
- mv -f .deps/libcoregrind_s390x_linux_a-m_oset.Tpo .deps/libcoregrind_s390x_linux_a-m_oset.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vkiscnums.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Tpo -c -o libcoregrind_s390x_linux_a-m_vkiscnums.o `test -f 'm_vkiscnums.c' || echo './'`m_vkiscnums.c
- m_translate.c: In function 'vgPlain_translate':
- m_translate.c:1548: error: 'VexTranslateArgs' has no member named 'dispatch'
- make[3]: *** [libcoregrind_s390x_linux_a-m_translate.o] Error 1
- make[3]: *** Waiting for unfinished jobs....
- mv -f .deps/libcoregrind_s390x_linux_a-m_vki.Tpo .deps/libcoregrind_s390x_linux_a-m_vki.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Tpo .deps/libcoregrind_s390x_linux_a-m_vkiscnums.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_tooliface.Tpo .deps/libcoregrind_s390x_linux_a-m_tooliface.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_signals.Tpo .deps/libcoregrind_s390x_linux_a-m_signals.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_mallocfree.Tpo .deps/libcoregrind_s390x_linux_a-m_mallocfree.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo .deps/libcoregrind_s390x_linux_a-m_transtab.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_main.Tpo .deps/libcoregrind_s390x_linux_a-m_main.Po
- make[3]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old/coregrind'
- make[2]: *** [all] Error 2
- make[2]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old/coregrind'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/home0/cborntra/valgrind-nightly/valgrind-old'
- make: *** [all] Error 2
--- 3,19 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 476 tests, 6 stderr failures, 0 stdout failures, 3 stderrB failures, 0 stdoutB failures, 0 post failures ==
! gdbserver_tests/mcbreak (stderrB)
! gdbserver_tests/mcclean_after_fork (stderrB)
! gdbserver_tests/mssnapshot (stderrB)
! none/tests/faultstatus (stderr)
! helgrind/tests/tc06_two_races_xml (stderr)
! helgrind/tests/tc23_bogus_condwait (stderr)
! drd/tests/tc04_free_lock (stderr)
! drd/tests/tc09_bad_unlock (stderr)
! drd/tests/tc23_bogus_condwait (stderr)
|
|
From: Christian B. <bor...@de...> - 2011-05-30 20:22:12
|
Nightly build on fedora390 ( Fedora 13/14/15 mix with gcc 3.5.3 on z196 (s390x) )
Started at 2011-05-30 22:10:01 CEST
Ended at 2011-05-30 22:21:19 CEST
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 476 tests, 6 stderr failures, 0 stdout failures, 0 stderrB failures, 0 stdoutB failures, 0 post failures ==
helgrind/tests/tc06_two_races_xml (stderr)
helgrind/tests/tc20_verifywrap (stderr)
helgrind/tests/tc23_bogus_condwait (stderr)
drd/tests/tc04_free_lock (stderr)
drd/tests/tc09_bad_unlock (stderr)
drd/tests/tc23_bogus_condwait (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -mzarch -march=z900 -m64 -g -Wno-long-long -MT libcoregrind_s390x_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_trampoline.Tpo -c -o libcoregrind_s390x_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
mv -f .deps/libcoregrind_s390x_linux_a-m_trampoline.Tpo .deps/libcoregrind_s390x_linux_a-m_trampoline.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_translate.Tpo -c -o libcoregrind_s390x_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
mv -f .deps/libcoregrind_s390x_linux_a-m_threadstate.Tpo .deps/libcoregrind_s390x_linux_a-m_threadstate.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_transtab.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo -c -o libcoregrind_s390x_linux_a-m_transtab.o `test -f 'm_transtab.c' || echo './'`m_transtab.c
m_translate.c: In function 'vgPlain_translate':
m_translate.c:1548:7: error: 'VexTranslateArgs' has no member named 'dispatch'
mv -f .deps/libcoregrind_s390x_linux_a-m_main.Tpo .deps/libcoregrind_s390x_linux_a-m_main.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vki.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vki.Tpo -c -o libcoregrind_s390x_linux_a-m_vki.o `test -f 'm_vki.c' || echo './'`m_vki.c
make[3]: *** [libcoregrind_s390x_linux_a-m_translate.o] Error 1
make[3]: *** Waiting for unfinished jobs....
mv -f .deps/libcoregrind_s390x_linux_a-m_vki.Tpo .deps/libcoregrind_s390x_linux_a-m_vki.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_tooliface.Tpo .deps/libcoregrind_s390x_linux_a-m_tooliface.Po
mv -f .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo .deps/libcoregrind_s390x_linux_a-m_transtab.Po
make[3]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old/coregrind'
make[2]: *** [all] Error 2
make[2]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old/coregrind'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Mon May 30 22:10:49 2011
--- new.short Mon May 30 22:21:19 2011
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -mzarch -march=z900 -m64 -g -Wno-long-long -MT libcoregrind_s390x_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_trampoline.Tpo -c -o libcoregrind_s390x_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
- mv -f .deps/libcoregrind_s390x_linux_a-m_trampoline.Tpo .deps/libcoregrind_s390x_linux_a-m_trampoline.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_translate.Tpo -c -o libcoregrind_s390x_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
- mv -f .deps/libcoregrind_s390x_linux_a-m_threadstate.Tpo .deps/libcoregrind_s390x_linux_a-m_threadstate.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_transtab.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo -c -o libcoregrind_s390x_linux_a-m_transtab.o `test -f 'm_transtab.c' || echo './'`m_transtab.c
- m_translate.c: In function 'vgPlain_translate':
- m_translate.c:1548:7: error: 'VexTranslateArgs' has no member named 'dispatch'
- mv -f .deps/libcoregrind_s390x_linux_a-m_main.Tpo .deps/libcoregrind_s390x_linux_a-m_main.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_s390x=1 -DVGO_linux=1 -DVGP_s390x_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/cborntra/valgrind-nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"s390x-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_s390x_linux_a-m_vki.o -MD -MP -MF .deps/libcoregrind_s390x_linux_a-m_vki.Tpo -c -o libcoregrind_s390x_linux_a-m_vki.o `test -f 'm_vki.c' || echo './'`m_vki.c
- make[3]: *** [libcoregrind_s390x_linux_a-m_translate.o] Error 1
- make[3]: *** Waiting for unfinished jobs....
- mv -f .deps/libcoregrind_s390x_linux_a-m_vki.Tpo .deps/libcoregrind_s390x_linux_a-m_vki.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_tooliface.Tpo .deps/libcoregrind_s390x_linux_a-m_tooliface.Po
- mv -f .deps/libcoregrind_s390x_linux_a-m_transtab.Tpo .deps/libcoregrind_s390x_linux_a-m_transtab.Po
- make[3]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old/coregrind'
- make[2]: *** [all] Error 2
- make[2]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old/coregrind'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/home/cborntra/valgrind-nightly/valgrind-old'
- make: *** [all] Error 2
--- 3,16 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 476 tests, 6 stderr failures, 0 stdout failures, 0 stderrB failures, 0 stdoutB failures, 0 post failures ==
! helgrind/tests/tc06_two_races_xml (stderr)
! helgrind/tests/tc20_verifywrap (stderr)
! helgrind/tests/tc23_bogus_condwait (stderr)
! drd/tests/tc04_free_lock (stderr)
! drd/tests/tc09_bad_unlock (stderr)
! drd/tests/tc23_bogus_condwait (stderr)
|
|
From: <sv...@va...> - 2011-05-30 10:23:50
|
Author: sewardj
Date: 2011-05-30 11:18:59 +0100 (Mon, 30 May 2011)
New Revision: 11790
Log:
Handle ELF objects with two .eh_frame sections. This fixes a problem
handling libxul.so when linked by gold on x86_64. (n-i-bz)
Modified:
trunk/coregrind/m_debuginfo/debuginfo.c
trunk/coregrind/m_debuginfo/priv_readdwarf.h
trunk/coregrind/m_debuginfo/priv_storage.h
trunk/coregrind/m_debuginfo/readdwarf.c
trunk/coregrind/m_debuginfo/readelf.c
Modified: trunk/coregrind/m_debuginfo/debuginfo.c
===================================================================
--- trunk/coregrind/m_debuginfo/debuginfo.c 2011-05-30 06:29:39 UTC (rev 11789)
+++ trunk/coregrind/m_debuginfo/debuginfo.c 2011-05-30 10:18:59 UTC (rev 11790)
@@ -187,8 +187,8 @@
di->memname = memname ? ML_(dinfo_strdup)("di.debuginfo.aDI.3", memname)
: NULL;
- /* Everything else -- pointers, sizes, arrays -- is zeroed by calloc.
- Now set up the debugging-output flags. */
+ /* Everything else -- pointers, sizes, arrays -- is zeroed by
+ ML_(dinfo_zalloc). Now set up the debugging-output flags. */
traceme
= VG_(string_match)( VG_(clo_trace_symtab_patt), filename )
|| (memname && VG_(string_match)( VG_(clo_trace_symtab_patt),
Modified: trunk/coregrind/m_debuginfo/priv_readdwarf.h
===================================================================
--- trunk/coregrind/m_debuginfo/priv_readdwarf.h 2011-05-30 06:29:39 UTC (rev 11789)
+++ trunk/coregrind/m_debuginfo/priv_readdwarf.h 2011-05-30 10:18:59 UTC (rev 11790)
@@ -62,7 +62,9 @@
-------------------- */
extern
void ML_(read_callframe_info_dwarf3)
- ( /*OUT*/struct _DebugInfo* di, UChar* frame, SizeT frame_sz, Bool for_eh );
+ ( /*OUT*/struct _DebugInfo* di,
+ UChar* frame_image, SizeT frame_size, Addr frame_avma,
+ Bool is_ehframe );
#endif /* ndef __PRIV_READDWARF_H */
Modified: trunk/coregrind/m_debuginfo/priv_storage.h
===================================================================
--- trunk/coregrind/m_debuginfo/readdwarf.c 2011-05-30 06:29:39 UTC (rev 11789)
+++ trunk/coregrind/m_debuginfo/readdwarf.c 2011-05-30 10:18:59 UTC (rev 11790)
@@ -3708,29 +3708,41 @@
static CIE the_CIEs[N_CIEs];
+/* Read, summarise and store CFA unwind info from .eh_frame and
+ .debug_frame sections. is_ehframe tells us which kind we are
+ dealing with -- they are slightly different. */
void ML_(read_callframe_info_dwarf3)
- ( /*OUT*/struct _DebugInfo* di, UChar* frame_image, SizeT frame_size,
- Bool for_eh )
+ ( /*OUT*/struct _DebugInfo* di,
+ UChar* frame_image, SizeT frame_size, Addr frame_avma,
+ Bool is_ehframe )
{
Int nbytes;
HChar* how = NULL;
Int n_CIEs = 0;
UChar* data = frame_image;
- UWord ehframe_cfsis = 0;
- Addr frame_avma = for_eh ? di->ehframe_avma : 0;
+ UWord cfsi_used_orig;
+ /* If we're dealing with a .debug_frame, assume zero frame_avma. */
+ if (!is_ehframe)
+ vg_assert(frame_avma == 0);
+
# if defined(VGP_ppc32_linux) || defined(VGP_ppc64_linux)
/* These targets don't use CFI-based stack unwinding. */
return;
# endif
- /* If we are reading .debug_frame after .eh_frame has been read, only
- add FDEs which weren't covered in .eh_frame. To be able to quickly
- search the FDEs, the records must be sorted. */
- if ( ! for_eh && di->ehframe_size && di->cfsi_used ) {
+ /* If we read more than one .debug_frame or .eh_frame for this
+ DebugInfo*, the second and subsequent reads should only add FDEs
+ for address ranges not already covered by the FDEs already
+ present. To be able to quickly check which address ranges are
+ already present, any existing records (DiCFSIs) must be sorted,
+ so we can binary-search them in the code below. We also record
+ di->cfsi_used so that we know where the boundary is between
+ existing and new records. */
+ if (di->cfsi_used > 0) {
ML_(canonicaliseCFI) ( di );
- ehframe_cfsis = di->cfsi_used;
}
+ cfsi_used_orig = di->cfsi_used;
if (di->trace_cfi) {
VG_(printf)("\n-----------------------------------------------\n");
@@ -3825,7 +3837,7 @@
/* If cie_pointer is zero for .eh_frame or all ones for .debug_frame,
we've got a CIE; else it's an FDE. */
- if (cie_pointer == (for_eh ? 0ULL
+ if (cie_pointer == (is_ehframe ? 0ULL
: dw64 ? 0xFFFFFFFFFFFFFFFFULL : 0xFFFFFFFFULL)) {
Int this_CIE;
@@ -4040,7 +4052,7 @@
cie_pointer bytes back from here. */
/* re sizeof(UInt) / sizeof(ULong), matches XXX above. */
- if (for_eh)
+ if (is_ehframe)
look_for = (data - (dw64 ? sizeof(ULong) : sizeof(UInt))
- frame_image)
- cie_pointer;
@@ -4130,11 +4142,14 @@
data += fde_ilen;
- if (ehframe_cfsis) {
+ /* If this object's DebugInfo* had some DiCFSIs from a
+ previous .eh_frame or .debug_frame read, we must check
+ that we're not adding a duplicate. */
+ if (cfsi_used_orig > 0) {
Addr a_mid_lo, a_mid_hi;
Word mid, size,
lo = 0,
- hi = ehframe_cfsis-1;
+ hi = cfsi_used_orig-1;
while (True) {
/* current unsearched space is from lo to hi, inclusive. */
if (lo > hi) break; /* not found */
Modified: trunk/coregrind/m_debuginfo/readelf.c
===================================================================
--- trunk/coregrind/m_debuginfo/readelf.c 2011-05-30 06:29:39 UTC (rev 11789)
+++ trunk/coregrind/m_debuginfo/readelf.c 2011-05-30 10:18:59 UTC (rev 11790)
@@ -1446,6 +1446,7 @@
TRACE_SYMTAB("rw: contains svmas %#lx .. %#lx with bias %#lx\n",
rw_svma_base, rw_svma_limit - 1, rw_bias );
+ /* Iterate over section headers */
for (i = 0; i < shdr_nent; i++) {
ElfXX_Shdr* shdr = INDEX_BIS( shdr_img, i, shdr_ent_szB );
UChar* name = shdr_strtab_img + shdr->sh_name;
@@ -1801,19 +1802,22 @@
/* Accept .eh_frame where mapped as rx (code). This seems to be
the common case. However, if that doesn't pan out, try for
- rw (data) instead. */
+ rw (data) instead. We can handle up to N_EHFRAME_SECTS per
+ ELF object. */
if (0 == VG_(strcmp)(name, ".eh_frame")) {
- if (inrx && size > 0 && !di->ehframe_present) {
- di->ehframe_present = True;
- di->ehframe_avma = svma + rx_bias;
- di->ehframe_size = size;
- TRACE_SYMTAB("acquiring .eh_frame avma = %#lx\n", di->ehframe_avma);
+ if (inrx && size > 0 && di->n_ehframe < N_EHFRAME_SECTS) {
+ di->ehframe_avma[di->n_ehframe] = svma + rx_bias;
+ di->ehframe_size[di->n_ehframe] = size;
+ TRACE_SYMTAB("acquiring .eh_frame avma = %#lx\n",
+ di->ehframe_avma[di->n_ehframe]);
+ di->n_ehframe++;
} else
- if (inrw && size > 0 && !di->ehframe_present) {
- di->ehframe_present = True;
- di->ehframe_avma = svma + rw_bias;
- di->ehframe_size = size;
- TRACE_SYMTAB("acquiring .eh_frame avma = %#lx\n", di->ehframe_avma);
+ if (inrw && size > 0 && di->n_ehframe < N_EHFRAME_SECTS) {
+ di->ehframe_avma[di->n_ehframe] = svma + rw_bias;
+ di->ehframe_size[di->n_ehframe] = size;
+ TRACE_SYMTAB("acquiring .eh_frame avma = %#lx\n",
+ di->ehframe_avma[di->n_ehframe]);
+ di->n_ehframe++;
} else {
BAD(".eh_frame");
}
@@ -1857,9 +1861,10 @@
UChar* debug_frame_img = NULL; /* .debug_frame (dwarf2) */
UChar* dwarf1d_img = NULL; /* .debug (dwarf1) */
UChar* dwarf1l_img = NULL; /* .line (dwarf1) */
- UChar* ehframe_img = NULL; /* .eh_frame (dwarf2) */
UChar* opd_img = NULL; /* .opd (dwarf2,
ppc64-linux) */
+ UChar* ehframe_img[N_EHFRAME_SECTS]; /* .eh_frame (dwarf2) */
+
/* Section sizes, in bytes */
SizeT strtab_sz = 0;
SizeT symtab_sz = 0;
@@ -1877,44 +1882,60 @@
SizeT debug_frame_sz = 0;
SizeT dwarf1d_sz = 0;
SizeT dwarf1l_sz = 0;
- SizeT ehframe_sz = 0;
SizeT opd_sz_unused = 0;
+ SizeT ehframe_sz[N_EHFRAME_SECTS];
+ for (i = 0; i < N_EHFRAME_SECTS; i++) {
+ ehframe_img[i] = NULL;
+ ehframe_sz[i] = 0;
+ }
+
/* Find all interesting sections */
- /* What FIND does: it finds the section called SEC_NAME. The
- size of it is assigned to SEC_SIZE. The address of the
+ UInt ehframe_ix = 0;
+
+ /* What FIND does: it finds the section called _SEC_NAME. The
+ size of it is assigned to _SEC_SIZE. The address of the
section in the transiently loaded oimage is assigned to
- SEC_FILEA. Even for sections which are marked loadable, the
- client's ld.so may not have loaded them yet, so there is no
- guarantee that we can safely prod around in any such area).
- Because the entire object file is transiently mapped aboard
- for inspection, it's always safe to inspect that area. */
+ _SEC_IMG. If the section is found, _POST_FX is executed
+ after _SEC_NAME and _SEC_SIZE have been assigned to.
+ Even for sections which are marked loadable, the client's
+ ld.so may not have loaded them yet, so there is no guarantee
+ that we can safely prod around in any such area). Because
+ the entire object file is transiently mapped aboard for
+ inspection, it's always safe to inspect that area. */
+
+ /* Iterate over section headers (again) */
for (i = 0; i < ehdr_img->e_shnum; i++) {
-# define FIND(sec_name, sec_size, sec_img) \
+# define FINDX(_sec_name, _sec_size, _sec_img, _post_fx) \
do { ElfXX_Shdr* shdr \
= INDEX_BIS( shdr_img, i, shdr_ent_szB ); \
- if (0 == VG_(strcmp)(sec_name, shdr_strtab_img \
- + shdr->sh_name)) { \
+ if (0 == VG_(strcmp)(_sec_name, shdr_strtab_img \
+ + shdr->sh_name)) { \
Bool nobits; \
- sec_img = (void*)(oimage + shdr->sh_offset); \
- sec_size = shdr->sh_size; \
- nobits = shdr->sh_type == SHT_NOBITS; \
+ _sec_img = (void*)(oimage + shdr->sh_offset); \
+ _sec_size = shdr->sh_size; \
+ nobits = shdr->sh_type == SHT_NOBITS; \
TRACE_SYMTAB( "%18s: img %p .. %p\n", \
- sec_name, (UChar*)sec_img, \
- ((UChar*)sec_img) + sec_size - 1); \
+ _sec_name, (UChar*)_sec_img, \
+ ((UChar*)_sec_img) + _sec_size - 1); \
/* SHT_NOBITS sections have zero size in the file. */ \
if ( shdr->sh_offset \
- + (nobits ? 0 : sec_size) > n_oimage ) { \
+ + (nobits ? 0 : _sec_size) > n_oimage ) { \
ML_(symerr)(di, True, \
" section beyond image end?!"); \
goto out; \
} \
+ _post_fx; \
} \
} while (0);
+ /* Version with no post-effects */
+# define FIND(_sec_name, _sec_size, _sec_img) \
+ FINDX(_sec_name, _sec_size, _sec_img, /**/)
+
/* NAME SIZE IMAGE addr */
FIND(".dynsym", dynsym_sz, dynsym_img)
FIND(".dynstr", dynstr_sz, dynstr_img)
@@ -1936,10 +1957,27 @@
FIND(".debug", dwarf1d_sz, dwarf1d_img)
FIND(".line", dwarf1l_sz, dwarf1l_img)
- FIND(".eh_frame", ehframe_sz, ehframe_img)
FIND(".opd", opd_sz_unused, opd_img)
+ FINDX(".eh_frame", ehframe_sz[ehframe_ix],
+ ehframe_img[ehframe_ix],
+ do { ehframe_ix++; vg_assert(ehframe_ix <= N_EHFRAME_SECTS); }
+ while (0)
+ )
+ /* Comment_on_EH_FRAME_MULTIPLE_INSTANCES: w.r.t. .eh_frame
+ multi-instance kludgery, how are we assured that the order
+ in which we fill in ehframe_sz[] and ehframe_img[] is
+ consistent with the order in which we previously filled in
+ di->ehframe_avma[] and di->ehframe_size[] ? By the fact
+ that in both cases, these arrays were filled in by
+ iterating over the section headers top-to-bottom. So both
+ loops (this one and the previous one) encounter the
+ .eh_frame entries in the same order and so fill in these
+ arrays in a consistent order.
+ */
+
+# undef FINDX
# undef FIND
}
@@ -2176,14 +2214,24 @@
False, opd_img);
}
- /* Read .eh_frame and .debug_frame (call-frame-info) if any */
- if (ehframe_img) {
- vg_assert(ehframe_sz == di->ehframe_size);
- ML_(read_callframe_info_dwarf3)( di, ehframe_img, ehframe_sz, True );
+ /* Read .eh_frame and .debug_frame (call-frame-info) if any. Do
+ the .eh_frame section(s) first. */
+ vg_assert(di->n_ehframe >= 0 && di->n_ehframe <= N_EHFRAME_SECTS);
+ for (i = 0; i < di->n_ehframe; i++) {
+ /* see Comment_on_EH_FRAME_MULTIPLE_INSTANCES above for why
+ this next assertion should hold. */
+ vg_assert(ehframe_sz[i] == di->ehframe_size[i]);
+ ML_(read_callframe_info_dwarf3)( di,
+ ehframe_img[i],
+ ehframe_sz[i],
+ di->ehframe_avma[i],
+ True/*is_ehframe*/ );
}
if (debug_frame_sz) {
- ML_(read_callframe_info_dwarf3)( di, debug_frame_img,
- debug_frame_sz, False );
+ ML_(read_callframe_info_dwarf3)( di,
+ debug_frame_img, debug_frame_sz,
+ 0/*assume zero avma*/,
+ False/*!is_ehframe*/ );
}
/* Read the stabs and/or dwarf2 debug information, if any. It
|
|
From: <sv...@va...> - 2011-05-30 06:34:30
|
Author: sewardj
Date: 2011-05-30 07:29:39 +0100 (Mon, 30 May 2011)
New Revision: 11789
Log:
Un-break all non x86/amd64 targets following r11786, duh.
Modified:
trunk/coregrind/m_translate.c
Modified: trunk/coregrind/m_translate.c
===================================================================
--- trunk/coregrind/m_translate.c 2011-05-29 12:40:27 UTC (rev 11788)
+++ trunk/coregrind/m_translate.c 2011-05-30 06:29:39 UTC (rev 11789)
@@ -1544,8 +1544,11 @@
# elif defined(VGA_ppc32) || defined(VGA_ppc64) \
|| defined(VGA_arm) || defined(VGA_s390x)
- /* See comment libvex.h; machine has link register --> dipatch = NULL */
- vta.dispatch = NULL;
+ /* See comment in libvex.h. This target uses a
+ return-to-link-register scheme to get back to the dispatcher, so
+ both fields are NULL. */
+ vta.dispatch_assisted = NULL;
+ vta.dispatch_unassisted = NULL;
# else
# error "Unknown arch"
|
|
From: Bart V. A. <bva...@ac...> - 2011-05-30 06:30:10
|
Nightly build on cellbuzz-native ( cellbuzz, ppc64, Fedora 7, native ) Started at 2011-05-30 02:00:06 EDT Ended at 2011-05-30 02:30:00 EDT Results differ from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... done Last 20 lines of verbose log follow echo make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' make check-am make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' make[3]: Nothing to be done for `check-am'. make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' Making check in coregrind make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make check-am make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_ppc64=1 -DVGO_linux=1 -DVGP_ppc64_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/bart/software/valgrind/nightly/valgrind-new/Inst/lib/valgrind"\" -DVG_PLATFORM="\"ppc64-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_ppc64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_ppc64_linux_a-m_translate.Tpo -c -o libcoregrind_ppc64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c m_translate.c: In function 'vgPlain_translate': m_translate.c:1548: error: 'VexTranslateArgs' has no member named 'dispatch' make[3]: *** [libcoregrind_ppc64_linux_a-m_translate.o] Error 1 make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make[2]: *** [check] Error 2 make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make[1]: *** [check-recursive] Error 1 make[1]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new' make: *** [check] Error 2 ================================================= == Results from 24 hours ago == ================================================= Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... done Last 20 lines of verbose log follow echo make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' make check-am make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' make[3]: Nothing to be done for `check-am'. make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' Making check in coregrind make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make check-am make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_ppc64=1 -DVGO_linux=1 -DVGP_ppc64_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/bart/software/valgrind/nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"ppc64-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_ppc64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_ppc64_linux_a-m_translate.Tpo -c -o libcoregrind_ppc64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c m_translate.c: In function 'vgPlain_translate': m_translate.c:1534: error: 'VexTranslateArgs' has no member named 'dispatch' make[3]: *** [libcoregrind_ppc64_linux_a-m_translate.o] Error 1 make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make[2]: *** [check] Error 2 make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make[1]: *** [check-recursive] Error 1 make[1]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old' make: *** [check] Error 2 ================================================= == Difference between 24 hours ago and now == ================================================= *** old.short Mon May 30 02:15:54 2011 --- new.short Mon May 30 02:30:00 2011 *************** *** 7,27 **** Last 20 lines of verbose log follow echo ! make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' make check-am ! make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' make[3]: Nothing to be done for `check-am'. ! make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' ! make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/VEX' Making check in coregrind ! make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make check-am ! make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' ! gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_ppc64=1 -DVGO_linux=1 -DVGP_ppc64_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/bart/software/valgrind/nightly/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"ppc64-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_ppc64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_ppc64_linux_a-m_translate.Tpo -c -o libcoregrind_ppc64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c m_translate.c: In function 'vgPlain_translate': ! m_translate.c:1534: error: 'VexTranslateArgs' has no member named 'dispatch' make[3]: *** [libcoregrind_ppc64_linux_a-m_translate.o] Error 1 ! make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make[2]: *** [check] Error 2 ! make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old/coregrind' make[1]: *** [check-recursive] Error 1 ! make[1]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-old' make: *** [check] Error 2 --- 7,27 ---- Last 20 lines of verbose log follow echo ! make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' make check-am ! make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' make[3]: Nothing to be done for `check-am'. ! make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' ! make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/VEX' Making check in coregrind ! make[2]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make check-am ! make[3]: Entering directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' ! gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_ppc64=1 -DVGO_linux=1 -DVGP_ppc64_linux=1 -I../coregrind -DVG_LIBDIR="\"/home/bart/software/valgrind/nightly/valgrind-new/Inst/lib/valgrind"\" -DVG_PLATFORM="\"ppc64-linux\"" -m64 -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_ppc64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_ppc64_linux_a-m_translate.Tpo -c -o libcoregrind_ppc64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c m_translate.c: In function 'vgPlain_translate': ! m_translate.c:1548: error: 'VexTranslateArgs' has no member named 'dispatch' make[3]: *** [libcoregrind_ppc64_linux_a-m_translate.o] Error 1 ! make[3]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make[2]: *** [check] Error 2 ! make[2]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new/coregrind' make[1]: *** [check-recursive] Error 1 ! make[1]: Leaving directory `/net/home/bart/software/valgrind/nightly/valgrind-new' make: *** [check] Error 2 |
|
From: Tom H. <th...@cy...> - 2011-05-30 02:38:38
|
Nightly build on vauxhall ( x86_64, Fedora 14 )
Started at 2011-05-30 03:20:03 BST
Ended at 2011-05-30 03:38:21 BST
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 566 tests, 4 stderr failures, 0 stdout failures, 1 stderrB failure, 1 stdoutB failure, 0 post failures ==
gdbserver_tests/mcinfcallWSRU (stderrB)
gdbserver_tests/nlcontrolc (stdoutB)
memcheck/tests/linux/stack_switch (stderr)
memcheck/tests/origin5-bz2 (stderr)
helgrind/tests/tc06_two_races_xml (stderr)
exp-sgcheck/tests/bad_percentify (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
m_translate.c: In function 'vgPlain_translate':
m_translate.c:1519:7: error: 'VexTranslateArgs' has no member named 'dispatch'
make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[2]: *** [all] Error 2
make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Mon May 30 03:22:14 2011
--- new.short Mon May 30 03:38:21 2011
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
- mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
- m_translate.c: In function 'vgPlain_translate':
- m_translate.c:1519:7: error: 'VexTranslateArgs' has no member named 'dispatch'
- make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
- make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[2]: *** [all] Error 2
- make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
- make: *** [all] Error 2
--- 3,16 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 566 tests, 4 stderr failures, 0 stdout failures, 1 stderrB failure, 1 stdoutB failure, 0 post failures ==
! gdbserver_tests/mcinfcallWSRU (stderrB)
! gdbserver_tests/nlcontrolc (stdoutB)
! memcheck/tests/linux/stack_switch (stderr)
! memcheck/tests/origin5-bz2 (stderr)
! helgrind/tests/tc06_two_races_xml (stderr)
! exp-sgcheck/tests/bad_percentify (stderr)
|
|
From: Tom H. <th...@cy...> - 2011-05-30 02:35:28
|
Nightly build on bristol ( x86_64, Fedora 15 )
Started at 2011-05-30 03:20:02 BST
Ended at 2011-05-30 03:35:11 BST
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 570 tests, 23 stderr failures, 1 stdout failure, 1 stderrB failure, 1 stdoutB failure, 0 post failures ==
gdbserver_tests/mcinfcallWSRU (stderrB)
gdbserver_tests/nlcontrolc (stdoutB)
memcheck/tests/origin5-bz2 (stderr)
memcheck/tests/overlap (stderr)
cachegrind/tests/chdir (stderr)
cachegrind/tests/clreq (stderr)
cachegrind/tests/dlclose (stderr)
cachegrind/tests/notpower2 (stderr)
cachegrind/tests/wrap5 (stderr)
cachegrind/tests/x86/fpu-28-108 (stderr)
callgrind/tests/notpower2-hwpref (stderr)
callgrind/tests/notpower2-use (stderr)
callgrind/tests/notpower2-wb (stderr)
callgrind/tests/notpower2 (stderr)
callgrind/tests/simwork-both (stderr)
callgrind/tests/simwork-cache (stderr)
callgrind/tests/simwork1 (stderr)
callgrind/tests/simwork2 (stderr)
callgrind/tests/simwork3 (stderr)
callgrind/tests/threads-use (stderr)
none/tests/amd64/bug127521-64 (stdout)
none/tests/amd64/bug127521-64 (stderr)
none/tests/shell (stderr)
helgrind/tests/hg05_race2 (stderr)
helgrind/tests/tc06_two_races_xml (stderr)
exp-sgcheck/tests/bad_percentify (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
m_translate.c: In function 'vgPlain_translate':
m_translate.c:1519:7: error: 'VexTranslateArgs' has no member named 'dispatch'
make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[2]: *** [all] Error 2
make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Mon May 30 03:21:45 2011
--- new.short Mon May 30 03:35:11 2011
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
- mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
- m_translate.c: In function 'vgPlain_translate':
- m_translate.c:1519:7: error: 'VexTranslateArgs' has no member named 'dispatch'
- make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
- make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[2]: *** [all] Error 2
- make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
- make: *** [all] Error 2
--- 3,36 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 570 tests, 23 stderr failures, 1 stdout failure, 1 stderrB failure, 1 stdoutB failure, 0 post failures ==
! gdbserver_tests/mcinfcallWSRU (stderrB)
! gdbserver_tests/nlcontrolc (stdoutB)
! memcheck/tests/origin5-bz2 (stderr)
! memcheck/tests/overlap (stderr)
! cachegrind/tests/chdir (stderr)
! cachegrind/tests/clreq (stderr)
! cachegrind/tests/dlclose (stderr)
! cachegrind/tests/notpower2 (stderr)
! cachegrind/tests/wrap5 (stderr)
! cachegrind/tests/x86/fpu-28-108 (stderr)
! callgrind/tests/notpower2-hwpref (stderr)
! callgrind/tests/notpower2-use (stderr)
! callgrind/tests/notpower2-wb (stderr)
! callgrind/tests/notpower2 (stderr)
! callgrind/tests/simwork-both (stderr)
! callgrind/tests/simwork-cache (stderr)
! callgrind/tests/simwork1 (stderr)
! callgrind/tests/simwork2 (stderr)
! callgrind/tests/simwork3 (stderr)
! callgrind/tests/threads-use (stderr)
! none/tests/amd64/bug127521-64 (stdout)
! none/tests/amd64/bug127521-64 (stderr)
! none/tests/shell (stderr)
! helgrind/tests/hg05_race2 (stderr)
! helgrind/tests/tc06_two_races_xml (stderr)
! exp-sgcheck/tests/bad_percentify (stderr)
|
|
From: Tom H. <th...@cy...> - 2011-05-30 02:26:54
|
Nightly build on mg ( x86_64, Fedora 9 )
Started at 2011-05-30 03:10:03 BST
Ended at 2011-05-30 03:26:39 BST
Results differ from 24 hours ago
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... done
Running regression tests ... failed
Regression test results follow
== 569 tests, 4 stderr failures, 4 stdout failures, 1 stderrB failure, 2 stdoutB failures, 0 post failures ==
gdbserver_tests/mcclean_after_fork (stderr)
gdbserver_tests/mcclean_after_fork (stdoutB)
gdbserver_tests/mcinfcallWSRU (stderrB)
gdbserver_tests/mcwatchpoints (stdoutB)
none/tests/amd64/bug132918 (stdout)
none/tests/amd64/fxtract (stdout)
none/tests/amd64/sse4-64 (stdout)
none/tests/x86/fxtract (stdout)
helgrind/tests/tc06_two_races_xml (stderr)
helgrind/tests/tc20_verifywrap (stderr)
helgrind/tests/tc23_bogus_condwait (stderr)
=================================================
== Results from 24 hours ago ==
=================================================
Checking out valgrind source tree ... done
Configuring valgrind ... done
Building valgrind ... failed
Last 20 lines of verbose log follow echo
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
m_translate.c: In function 'vgPlain_translate':
m_translate.c:1519: error: 'VexTranslateArgs' has no member named 'dispatch'
make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[2]: *** [all] Error 2
make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
make[1]: *** [all-recursive] Error 1
make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
make: *** [all] Error 2
=================================================
== Difference between 24 hours ago and now ==
=================================================
*** old.short Mon May 30 03:11:59 2011
--- new.short Mon May 30 03:26:39 2011
***************
*** 3,26 ****
Configuring valgrind ... done
! Building valgrind ... failed
- Last 20 lines of verbose log follow echo
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_stacktrace.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo -c -o libcoregrind_amd64_linux_a-m_stacktrace.o `test -f 'm_stacktrace.c' || echo './'`m_stacktrace.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_stacktrace.Tpo .deps/libcoregrind_amd64_linux_a-m_stacktrace.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_syscall.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo -c -o libcoregrind_amd64_linux_a-m_syscall.o `test -f 'm_syscall.c' || echo './'`m_syscall.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_syscall.Tpo .deps/libcoregrind_amd64_linux_a-m_syscall.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_threadstate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo -c -o libcoregrind_amd64_linux_a-m_threadstate.o `test -f 'm_threadstate.c' || echo './'`m_threadstate.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_threadstate.Tpo .deps/libcoregrind_amd64_linux_a-m_threadstate.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_tooliface.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo -c -o libcoregrind_amd64_linux_a-m_tooliface.o `test -f 'm_tooliface.c' || echo './'`m_tooliface.c
- mv -f .deps/libcoregrind_amd64_linux_a-m_tooliface.Tpo .deps/libcoregrind_amd64_linux_a-m_tooliface.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -g -Wno-long-long -MT libcoregrind_amd64_linux_a-m_trampoline.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo -c -o libcoregrind_amd64_linux_a-m_trampoline.o `test -f 'm_trampoline.S' || echo './'`m_trampoline.S
- mv -f .deps/libcoregrind_amd64_linux_a-m_trampoline.Tpo .deps/libcoregrind_amd64_linux_a-m_trampoline.Po
- gcc -DHAVE_CONFIG_H -I. -I.. -I.. -I../include -I../VEX/pub -DVGA_amd64=1 -DVGO_linux=1 -DVGP_amd64_linux=1 -I../coregrind -DVG_LIBDIR="\"/tmp/vgtest/2011-05-30/valgrind-old/Inst/lib/valgrind"\" -DVG_PLATFORM="\"amd64-linux\"" -m64 -fomit-frame-pointer -O2 -g -Wall -Wmissing-prototypes -Wshadow -Wpointer-arith -Wstrict-prototypes -Wmissing-declarations -Wno-format-zero-length -fno-strict-aliasing -Wno-long-long -Wno-pointer-sign -fno-stack-protector -MT libcoregrind_amd64_linux_a-m_translate.o -MD -MP -MF .deps/libcoregrind_amd64_linux_a-m_translate.Tpo -c -o libcoregrind_amd64_linux_a-m_translate.o `test -f 'm_translate.c' || echo './'`m_translate.c
- m_translate.c: In function 'vgPlain_translate':
- m_translate.c:1519: error: 'VexTranslateArgs' has no member named 'dispatch'
- make[3]: *** [libcoregrind_amd64_linux_a-m_translate.o] Error 1
- make[3]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[2]: *** [all] Error 2
- make[2]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old/coregrind'
- make[1]: *** [all-recursive] Error 1
- make[1]: Leaving directory `/tmp/vgtest/2011-05-30/valgrind-old'
- make: *** [all] Error 2
--- 3,21 ----
Configuring valgrind ... done
! Building valgrind ... done
! Running regression tests ... failed
!
! Regression test results follow
!
! == 569 tests, 4 stderr failures, 4 stdout failures, 1 stderrB failure, 2 stdoutB failures, 0 post failures ==
! gdbserver_tests/mcclean_after_fork (stderr)
! gdbserver_tests/mcclean_after_fork (stdoutB)
! gdbserver_tests/mcinfcallWSRU (stderrB)
! gdbserver_tests/mcwatchpoints (stdoutB)
! none/tests/amd64/bug132918 (stdout)
! none/tests/amd64/fxtract (stdout)
! none/tests/amd64/sse4-64 (stdout)
! none/tests/x86/fxtract (stdout)
! helgrind/tests/tc06_two_races_xml (stderr)
! helgrind/tests/tc20_verifywrap (stderr)
! helgrind/tests/tc23_bogus_condwait (stderr)
|
--- trunk/coregrind/m_debuginfo/priv_storage.h 2011-05-30 06:29:39 UTC (rev 11789)
+++ trunk/coregrind/m_debuginfo/priv_storage.h 2011-05-30 10:18:59 UTC (rev 11790)
@@ -370,6 +370,12 @@
#define SEGINFO_STRCHUNKSIZE (64*1024)
+/* We may encounter more than one .eh_frame section in an object --
+ unusual but apparently allowed by ELF. See
+ http://sourceware.org/bugzilla/show_bug.cgi?id=12675
+*/
+#define N_EHFRAME_SECTS 2
+
struct _DebugInfo {
/* Admin stuff */
@@ -626,10 +632,11 @@
Bool opd_present;
Addr opd_avma;
SizeT opd_size;
- /* .ehframe -- needed on amd64-linux for stack unwinding */
- Bool ehframe_present;
- Addr ehframe_avma;
- SizeT ehframe_size;
+ /* .ehframe -- needed on amd64-linux for stack unwinding. We might
+ see more than one, hence the arrays. */
+ UInt n_ehframe; /* 0 .. N_EHFRAME_SECTS */
+ Addr ehframe_avma[N_EHFRAME_SECTS];
+ SizeT ehframe_size[N_EHFRAME_SECTS];
/* Sorted tables of stuff we snarfed from the file. This is the
eventual product of reading the debug info. All this stuff
Modified: trunk/coregrind/m_debuginfo/readdwarf.c
===================================================================